@@ -13,7 +13,7 @@ end
 def protect( place = nil )
   begin
     ret = yield
-  rescue Exception
+  rescue StandardError, NameError
     puts 'Error in ' + place if place
     _print_bt_all $!
     nil
