@@ -31,7 +31,13 @@ class Installer
                      'path for ruby extention' ],
     'ruby-path' => [ RubyParams::RUBY_PATH,
                      'path',
-                     'path of ruby interpreter' ]
+                     'path of ruby interpreter' ],
+    'with'      => [ '',
+                     'name',
+                     'package name(s) you want to install' ],
+    'without'   => [ '',
+                     'name',
+                     'package name(s) you do not want to install' ]
   }
 
   OptionOrder = %w( bin-dir rb-dir so-dir ruby-path )
@@ -98,7 +104,7 @@ class Installer
   def write_config
     File.open( ConfigFile, 'w' ) do |f|
       @config.each do |k,v|
-        f.printf "%s=%s\n", k, v
+        f.printf "%s=%s\n", k, v if v
       end
     end
   end
@@ -111,7 +117,7 @@ class Installer
   end
 
   def print_usage
-    print <<S
+    $stderr.print <<S
 
 Usage:
 
@@ -125,10 +131,29 @@ S
       default = i[0]
       arg     = i[1]
       desc    = i[2]
-      printf( "  %-20s %s [%s]\n",
-              "--#{name}=#{arg}", desc, default )
+      $stderr.printf( "  %-20s %s [%s]\n",
+                      "--#{name}=#{arg}", desc, default )
+    end
+    $stderr.puts
+  end
+
+  def install_packages( dflt = nil )
+    ret = @config['with'].split(',')
+    if ret.empty? then
+      ret = (dflt || type::PACKAGES).dup
+    end
+    @config['without'].split(',').each do |i|
+      ret.delete i
+    end
+    ret
+  end
+
+  def package( name )
+    if install_packages.include? name then
+      yield
+    else
+      $stderr.puts "inst.rb: skip package '#{name}' (user option)"
     end
-    puts
   end
 
 
@@ -139,12 +164,12 @@ S
       begin
         i.set_config ARGV
       rescue
-raise
-        puts $!
+        raise if $DEBUG
+        $stderr.puts $!
         exit 1
       end
       unless i.wrong_arg.empty? then
-        puts "unknown arguments '#{i.wrong_arg.join %<', '>}'"
+        $stderr.puts "unknown arguments '#{i.wrong_arg.join %<', '>}'"
         exit 1
       end
       i.execute
@@ -175,32 +200,32 @@ raise
   end
 
   def try_setup
-    puts 'entering setup phase...'
+    $stderr.puts 'entering setup phase...'
     begin
       com_setup
     rescue
-      puts 'setup failed'
+      $stderr.puts 'setup failed'
       raise
     end
-    puts 'setup done.'
+    $stderr.puts 'setup done.'
   end
 
   def try_install
-    puts 'entering install phase...'
+    $stderr.puts 'entering install phase...'
     begin
       com_install
     rescue
-      puts 'install failed'
+      $stderr.puts 'install failed'
       raise
     end
-    puts 'installation done.'
+    $stderr.puts 'installation done.'
   end
 
 
   def into_dir( libn )
     unless directory? libn then
       # for raw package
-      puts "inst.rb: skip #{libn} (not critical)"
+      $stderr.puts "inst.rb: skip package '#{libn}' (no dir)"
       return
     end
     chdir( libn ) do
@@ -239,9 +264,10 @@ raise
 
   def install_rb( to = nil )
     to ||= @config['rb-dir']
+    isdir to
     Dir.foreach( '.' ) do |fn|
       if /\.rb\z/o === fn and file? fn then
-        install fn, isdir( to ), 0644
+        install fn, to, 0644
       end
     end
   end
@@ -249,7 +275,7 @@ raise
 
   def extconf
     unless is_newer? 'Makefile', 'extconf.rb' then
-      system 'ruby extconf.rb'
+      system "#{@config['ruby-path']} extconf.rb"
     end
   end
 
