@@ -13,7 +13,7 @@ require 'amstd/rbparams'
 
 module RubyEmuration
 
-  WITH_EXT = /\.rb\z|\.#{RubyParams::DLEXT}\z/o
+  WITH_EXT = /\.(?:rb|#{RubyParams::DLEXT})\z/o
 
   def find_feature( feature )
     with_ext( feature ) do |fn|
@@ -32,7 +32,7 @@ module RubyEmuration
     if WITH_EXT === feature then
       yield feature
     else
-      Extentions.each do |ext|
+      ['rb', RubyParams::DLEXT].each do |ext|
         yield feature + '.' + ext
       end
     end
