@@ -4,30 +4,27 @@
 #   Copyright (c) 1999 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
 #
 
-require 'amstd/symbol'
-
 
 class Object
 
   private
 
   def _name2str( arg )
-    case arg
-    when String then arg
-    when Symbol then arg.id2name
+    if arg.respond_to? :id2name then
+      arg.id2name
     else
-      raise TypeError,
-        "wrong arg type #{arg.type} for expected String/Symbol"
+      arg.to_s
     end
   end
 
   def _type2str( arg )
+    if arg.respond_to? :id2name then
+      arg = arg.id2name
+    end
     case arg
     when String then arg
-    when Symbol then arg.id2name
+    when Array  then arg.collect{|i| _type2str i }.join(',')
     when Module then arg.name
-    when Array
-      arg.collect{|i| _type2str i }.join(',')
     else
       raise TypeError,
         "wrong arg type #{arg.type} for expected String/Symbol/Module/Array"
@@ -36,23 +33,18 @@ class Object
 
 
   def _name2simbol( arg )
-    case arg
-    when Symbol then arg
-    when String then arg.intern
+    if arg.respond_to? :id2name then
+      arg
     else
-      raise TypeError,
-        "wrong arg type #{arg.type} for expected String/Symbol"
+      arg.to_s.intern
     end
   end
 
   def _type2simbol( arg )
-    case arg
-    when String then arg.intern
-    when Symbol then arg
-    when Module then arg.name.intern
+    if arg.respond_to? :id2name then
+      arg
     else
-      raise TypeError,
-        "wrong arg type #{arg.type} for expected String/Symbol/Module"
+      arg.to_s.intern
     end
   end
 
