@@ -1,7 +1,7 @@
 #
 # scanner.rb
 #
-#   Copyright (c) 1999 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
+#   Copyright (c) 1999,2000 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -97,7 +97,7 @@ class Scanner
     s = arr[0]
     printf "%7d %-10s %s\n",
       @scan.restsize,
-      Symbol === s ? s.id2name : s.inspect,
+      s.respond_to?(:id2name) ? s.id2name : s.inspect,
       arr[1].inspect
   end
 
